@@ -46,14 +46,14 @@ class Pending(Resource):
 
     def refund_payment(self, data={}, **kwargs):
         url = "{}".format(URL.REFUNDS)
-        if "merchantPaymentId" not in data:
+        if "merchantRefundId" not in data:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS "
-                             "\x1b[0m for merchantPaymentId")
+                             "\x1b[0m for merchantRefundId")
         if "requestedAt" not in data:
             data['requestedAt'] = datetime.datetime.now().second
         if "paymentId" not in data:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS "
-                             "\x1b[0m for userAuthorizationId")
+                             "\x1b[0m for paymentId")
         if "amount" not in data["amount"]:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS "
                              "\x1b[0m for amount")
